import Vue from 'vue'
import VueRouter from 'vue-router'
import Home from '../views/Home.vue'
import Login from '../views/Login.vue'
import {OrderingBatches, OrderingBatch, OrderingBatchRow, OrderingBatchWorksheet} from '../views/ordering'
import {ReceivingBatches, ReceivingBatch, ReceivingBatchRow, ReceivingBatchRowReceive} from '../views/receiving'

Vue.use(VueRouter)

const routes = [
    {
        path: '/',
        name: 'Home',
        component: Home
    },
    {
        path: '/login',
        name: 'login',
        component: Login
    },
    {
        path: '/about',
        name: 'About',
        // route level code-splitting
        // this generates a separate chunk (about.[hash].js) for this route
        // which is lazy-loaded when the route is visited.
        component: () => import(/* webpackChunkName: "about" */ '../views/About.vue')
    },

    //////////////////////////////
    // Ordering
    //////////////////////////////
    {
        path: '/ordering/',
        name: 'ordering',
        component: OrderingBatches,
    },
    {
        path: '/ordering/new',
        name: 'ordering.new',
        component: OrderingBatch,
        props: {mode: 'creating'},
    },
    {
        path: '/ordering/:uuid',
        name: 'ordering.view',
        component: OrderingBatch,
        props: {mode: 'viewing'},
    },
    // {
    //     path: '/ordering/:uuid/edit',
    //     name: 'ordering.edit',
    //     component: OrderingBatch,
    //     props: {mode: 'editing'},
    // },
    {
        path: '/ordering/:uuid/execute',
        name: 'ordering.execute',
        component: OrderingBatch,
        props: {mode: 'executing'},
    },
    {
        path: '/ordering/rows/:uuid',
        name: 'ordering.rows.view',
        component: OrderingBatchRow,
        props: {mode: 'viewing'},
    },
    {
        path: '/ordering/rows/:uuid/edit',
        name: 'ordering.rows.edit',
        component: OrderingBatchRow,
        props: {mode: 'editing'},
    },
    {
        path: '/ordering/:uuid/worksheet',
        name: 'ordering.worksheet',
        component: OrderingBatchWorksheet,
    },

    //////////////////////////////
    // Receiving
    //////////////////////////////
    {
        path: '/receiving/',
        name: 'receiving',
        component: ReceivingBatches,
    },
    {
        path: '/receiving/new',
        name: 'receiving.new',
        component: ReceivingBatch,
        props: {mode: 'creating'},
    },
    {
        path: '/receiving/:uuid',
        name: 'receiving.view',
        component: ReceivingBatch,
        props: {mode: 'viewing'},
    },
    {
        path: '/receiving/:uuid/edit',
        name: 'receiving.edit',
        component: ReceivingBatch,
        props: {mode: 'editing'},
    },
    {
        path: '/receiving/rows/:uuid',
        name: 'receiving.rows.view',
        component: ReceivingBatchRow,
        props: {mode: 'viewing'},
    },
    {
        path: '/receiving/rows/:uuid/receive',
        name: 'receiving.rows.receive',
        component: ReceivingBatchRowReceive,
    },
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

export default router
